local map = vim.keymap.set
local dap = require("dap")
local term = require("nvterm.terminal")

map("n", "<C-left>", "<C-o>", { desc = "LSP Back" })
map("n", "<C-right>", "<C-i>", { desc = "LSP Forward" })

map("v", "<C-c>", '"+y', { desc = "Copy selected" })
map({ "i", "n" }, "<C-v>", '<ESC>"+p', { desc = "Past" })

map({ "n", "v", "i" }, "<C-s>", "<Cmd>w<CR>", { desc = "Save file" })
map({ "n", "v", "i" }, "<C-a>", "<ESC>ggVG", { desc = "Select all" })

map("n", "<C-S-left>", "<C-w>h", { desc = "switch window left" })
map("n", "<C-S-right>", "<C-w>l", { desc = "switch window right" })
map("n", "<C-S-down>", "<C-w>j", { desc = "switch window down" })
map("n", "<C-S-up>", "<C-w>k", { desc = "switch window up" })

map("n", "<C-/>", "gcc", { desc = "toggle comment", remap = true })
map("v", "<C-/>", "gc", { desc = "toggle comment", remap = true })

-- neo-tree
map({ "n", "v" }, "<leader>e", "<Cmd>Neotree<CR>", { desc = "nvimtree focus window" })
map({ "n", "v" }, "<leader>g", "<Cmd>Neotree git_status float<CR>", { desc = "open gis status" })
map({ "n", "v" }, "<C-q>", "<Cmd>BufferClose<CR>", { desc = "close window" })

-- telescope
map("n", "<leader>f", "<Cmd>Telescope live_grep<CR>", { desc = "telescope live grep" })
map("n", "<leader>r", "<Cmd>Telescope lsp_references<CR>", { desc = "telescope lsp references" })
map("n", "<leader>d", "<Cmd>Telescope lsp_definitions<CR>", { desc = "telescope lsp definitions" })

-- barbar
map("n", "<tab>", "<Cmd>BufferNext<CR>", { desc = "Next tab" })
map("n", "<S-tab>", "<Cmd>BufferPrevious<CR>", { desc = "Previous tab" })

-- dap
map("n", "<leader>bb", dap.toggle_breakpoint, { desc = "Toggle breakpoint" })

-- nvterm
map("n", "<leader>t", function()
	term.toggle("horizontal")
end, { desc = "Open terminal" })

-- searchbox
map({ "n", "v", "i" }, "<C-f>", function()
	require("searchbox").incsearch({
		modifier = "ignore-case",
	})
end, { desc = "Search in file" })

-- menu
local menu = require("menu")

map("n", "<A-CR>", function()
	local ft = vim.bo.ft
	if ft ~= "neo-tree" then
		menu.open(require("config.menu"), { border = true })
	end
end)

require("langmapper").automapping({ global = true, buffer = true })
